# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: preferences/v1/preferences.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='preferences/v1/preferences.proto',
  package='blueapi.preferences.v1',
  syntax='proto3',
  serialized_options=b'\n\035cloud.alphaus.api.preferencesB\020PreferencesProtoZ*github.com/alphauslabs/blueapi/preferences',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n preferences/v1/preferences.proto\x12\x16\x62lueapi.preferences.v1\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x0c\n\nPreference\"\x17\n\x15GetPreferencesRequest2\xa5\x02\n\x0bPreferences\x12v\n\x0eGetPreferences\x12-.blueapi.preferences.v1.GetPreferencesRequest\x1a\".blueapi.preferences.v1.Preference\"\x11\x82\xd3\xe4\x93\x02\x0b\x12\t/prefs/v1\x1a\x9d\x01\x92\x41\x99\x01\x12\x42(BETA) Preferences API. Base URL: https://api.alphaus.cloud/m/blue\x1aS\n\x12Service definition\x12=https://github.com/alphauslabs/blueapi/tree/main/preferences/B]\n\x1d\x63loud.alphaus.api.preferencesB\x10PreferencesProtoZ*github.com/alphauslabs/blueapi/preferencesb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__openapiv2_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_PREFERENCE = _descriptor.Descriptor(
  name='Preference',
  full_name='blueapi.preferences.v1.Preference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=150,
)


_GETPREFERENCESREQUEST = _descriptor.Descriptor(
  name='GetPreferencesRequest',
  full_name='blueapi.preferences.v1.GetPreferencesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=175,
)

DESCRIPTOR.message_types_by_name['Preference'] = _PREFERENCE
DESCRIPTOR.message_types_by_name['GetPreferencesRequest'] = _GETPREFERENCESREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Preference = _reflection.GeneratedProtocolMessageType('Preference', (_message.Message,), {
  'DESCRIPTOR' : _PREFERENCE,
  '__module__' : 'preferences.v1.preferences_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.preferences.v1.Preference)
  })
_sym_db.RegisterMessage(Preference)

GetPreferencesRequest = _reflection.GeneratedProtocolMessageType('GetPreferencesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREFERENCESREQUEST,
  '__module__' : 'preferences.v1.preferences_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.preferences.v1.GetPreferencesRequest)
  })
_sym_db.RegisterMessage(GetPreferencesRequest)


DESCRIPTOR._options = None

_PREFERENCES = _descriptor.ServiceDescriptor(
  name='Preferences',
  full_name='blueapi.preferences.v1.Preferences',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\222A\231\001\022B(BETA) Preferences API. Base URL: https://api.alphaus.cloud/m/blue\032S\n\022Service definition\022=https://github.com/alphauslabs/blueapi/tree/main/preferences/',
  create_key=_descriptor._internal_create_key,
  serialized_start=178,
  serialized_end=471,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetPreferences',
    full_name='blueapi.preferences.v1.Preferences.GetPreferences',
    index=0,
    containing_service=None,
    input_type=_GETPREFERENCESREQUEST,
    output_type=_PREFERENCE,
    serialized_options=b'\202\323\344\223\002\013\022\t/prefs/v1',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREFERENCES)

DESCRIPTOR.services_by_name['Preferences'] = _PREFERENCES

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/aws/recommendation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/aws/recommendation.proto',
  package='blueapi.api.aws',
  syntax='proto3',
  serialized_options=b'\n\035cloud.alphaus.blueapi.api.awsB\031ApiAwsRecommendationProtoZ*github.com/alphauslabs/blue-sdk-go/api/aws',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x61pi/aws/recommendation.proto\x12\x0f\x62lueapi.api.aws\"\x9e\x02\n\x12\x41wsRecommendations\x12\x42\n\x07summary\x18\x01 \x01(\x0b\x32\x31.blueapi.api.aws.ReservationRecommendationSummary\x12<\n\x11riRecommendations\x18\x02 \x03(\x0b\x32!.blueapi.api.aws.RiRecommendation\x12<\n\x11spRecommendations\x18\x03 \x03(\x0b\x32!.blueapi.api.aws.SpRecommendation\x12H\n\x11\x65stimatedCoverage\x18\x04 \x03(\x0b\x32-.blueapi.api.aws.ReservationEstimatedCoverage\"\xc9\x03\n\x10RiRecommendation\x12\x11\n\taccountId\x18\x01 \x01(\t\x12\x13\n\x0bproductCode\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x14\n\x0cinstanceType\x18\x04 \x01(\t\x12\x10\n\x08quantity\x18\x05 \x01(\x03\x12\x16\n\x0enormalizedUnit\x18\x06 \x01(\x01\x12\x17\n\x0foperatingSystem\x18\x07 \x01(\t\x12\x16\n\x0epreInstalledSW\x18\x08 \x01(\t\x12\x0f\n\x07tenancy\x18\t \x01(\t\x12\x14\n\x0condemandCost\x18\n \x01(\x01\x12\x14\n\x0condemandrate\x18\x0b \x01(\x01\x12\x0e\n\x06riRate\x18\x0c \x01(\x01\x12\x13\n\x0bupfrontCost\x18\r \x01(\x01\x12\x16\n\x0e\x64iscountedCost\x18\x0e \x01(\x01\x12\x1c\n\x14monthlyAmortizedCost\x18\x0f \x01(\x01\x12\x1c\n\x14monthlyRecurringCost\x18\x10 \x01(\x01\x12\x1c\n\x14yearlyDiscountedCost\x18\x11 \x01(\x01\x12\x15\n\rreductionRate\x18\x12 \x01(\x01\x12\x1f\n\x17\x65stimatedMonthlySavings\x18\x13 \x01(\x01\"\xb7\x02\n\x10SpRecommendation\x12\x11\n\taccountId\x18\x01 \x01(\t\x12\x17\n\x0fspProductFamily\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x16\n\x0einstanceFamily\x18\x04 \x01(\t\x12\x14\n\x0condemandCost\x18\x05 \x01(\x01\x12\x12\n\ncommitment\x18\x06 \x01(\x01\x12\x16\n\x0enormalizedUnit\x18\x07 \x01(\x01\x12\x16\n\x0e\x64iscountedCost\x18\x08 \x01(\x01\x12\x1d\n\x15monthlyDiscountedCost\x18\t \x01(\x01\x12\x1c\n\x14yearlyDiscountedCost\x18\n \x01(\x01\x12\x1f\n\x17\x65stimatedMonthlySavings\x18\x0b \x01(\x01\x12\x15\n\rreductionRate\x18\x0c \x01(\x01\"\xde\x01\n ReservationRecommendationSummary\x12\x19\n\x11totalOnDemandCost\x18\x01 \x01(\x01\x12\x1b\n\x13totalDiscountedCost\x18\x02 \x01(\x01\x12\"\n\x1atotalDiscountedMonthlyCost\x18\x03 \x01(\x01\x12!\n\x19totalDiscountedYearlyCost\x18\x04 \x01(\x01\x12\x15\n\rreductionRate\x18\x05 \x01(\x01\x12$\n\x1ctotalEstimatedMonthlySavings\x18\x06 \x01(\x01\"\x8c\x01\n\x1cReservationEstimatedCoverage\x12\x11\n\taccountId\x18\x01 \x01(\t\x12\x13\n\x0bproductCode\x18\x02 \x01(\t\x12\x12\n\nriCoverage\x18\x03 \x01(\x01\x12\x15\n\rec2SpCoverage\x18\x04 \x01(\x01\x12\x19\n\x11\x63omputeSpCoverage\x18\x05 \x01(\x01\x42\x66\n\x1d\x63loud.alphaus.blueapi.api.awsB\x19\x41piAwsRecommendationProtoZ*github.com/alphauslabs/blue-sdk-go/api/awsb\x06proto3'
)




_AWSRECOMMENDATIONS = _descriptor.Descriptor(
  name='AwsRecommendations',
  full_name='blueapi.api.aws.AwsRecommendations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='summary', full_name='blueapi.api.aws.AwsRecommendations.summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='riRecommendations', full_name='blueapi.api.aws.AwsRecommendations.riRecommendations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spRecommendations', full_name='blueapi.api.aws.AwsRecommendations.spRecommendations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estimatedCoverage', full_name='blueapi.api.aws.AwsRecommendations.estimatedCoverage', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=336,
)


_RIRECOMMENDATION = _descriptor.Descriptor(
  name='RiRecommendation',
  full_name='blueapi.api.aws.RiRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountId', full_name='blueapi.api.aws.RiRecommendation.accountId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCode', full_name='blueapi.api.aws.RiRecommendation.productCode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='blueapi.api.aws.RiRecommendation.location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceType', full_name='blueapi.api.aws.RiRecommendation.instanceType', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='blueapi.api.aws.RiRecommendation.quantity', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalizedUnit', full_name='blueapi.api.aws.RiRecommendation.normalizedUnit', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operatingSystem', full_name='blueapi.api.aws.RiRecommendation.operatingSystem', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preInstalledSW', full_name='blueapi.api.aws.RiRecommendation.preInstalledSW', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tenancy', full_name='blueapi.api.aws.RiRecommendation.tenancy', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ondemandCost', full_name='blueapi.api.aws.RiRecommendation.ondemandCost', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ondemandrate', full_name='blueapi.api.aws.RiRecommendation.ondemandrate', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='riRate', full_name='blueapi.api.aws.RiRecommendation.riRate', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upfrontCost', full_name='blueapi.api.aws.RiRecommendation.upfrontCost', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discountedCost', full_name='blueapi.api.aws.RiRecommendation.discountedCost', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monthlyAmortizedCost', full_name='blueapi.api.aws.RiRecommendation.monthlyAmortizedCost', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monthlyRecurringCost', full_name='blueapi.api.aws.RiRecommendation.monthlyRecurringCost', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yearlyDiscountedCost', full_name='blueapi.api.aws.RiRecommendation.yearlyDiscountedCost', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reductionRate', full_name='blueapi.api.aws.RiRecommendation.reductionRate', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estimatedMonthlySavings', full_name='blueapi.api.aws.RiRecommendation.estimatedMonthlySavings', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=796,
)


_SPRECOMMENDATION = _descriptor.Descriptor(
  name='SpRecommendation',
  full_name='blueapi.api.aws.SpRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountId', full_name='blueapi.api.aws.SpRecommendation.accountId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spProductFamily', full_name='blueapi.api.aws.SpRecommendation.spProductFamily', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='blueapi.api.aws.SpRecommendation.location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceFamily', full_name='blueapi.api.aws.SpRecommendation.instanceFamily', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ondemandCost', full_name='blueapi.api.aws.SpRecommendation.ondemandCost', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commitment', full_name='blueapi.api.aws.SpRecommendation.commitment', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalizedUnit', full_name='blueapi.api.aws.SpRecommendation.normalizedUnit', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discountedCost', full_name='blueapi.api.aws.SpRecommendation.discountedCost', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monthlyDiscountedCost', full_name='blueapi.api.aws.SpRecommendation.monthlyDiscountedCost', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yearlyDiscountedCost', full_name='blueapi.api.aws.SpRecommendation.yearlyDiscountedCost', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estimatedMonthlySavings', full_name='blueapi.api.aws.SpRecommendation.estimatedMonthlySavings', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reductionRate', full_name='blueapi.api.aws.SpRecommendation.reductionRate', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=799,
  serialized_end=1110,
)


_RESERVATIONRECOMMENDATIONSUMMARY = _descriptor.Descriptor(
  name='ReservationRecommendationSummary',
  full_name='blueapi.api.aws.ReservationRecommendationSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='totalOnDemandCost', full_name='blueapi.api.aws.ReservationRecommendationSummary.totalOnDemandCost', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalDiscountedCost', full_name='blueapi.api.aws.ReservationRecommendationSummary.totalDiscountedCost', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalDiscountedMonthlyCost', full_name='blueapi.api.aws.ReservationRecommendationSummary.totalDiscountedMonthlyCost', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalDiscountedYearlyCost', full_name='blueapi.api.aws.ReservationRecommendationSummary.totalDiscountedYearlyCost', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reductionRate', full_name='blueapi.api.aws.ReservationRecommendationSummary.reductionRate', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalEstimatedMonthlySavings', full_name='blueapi.api.aws.ReservationRecommendationSummary.totalEstimatedMonthlySavings', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1113,
  serialized_end=1335,
)


_RESERVATIONESTIMATEDCOVERAGE = _descriptor.Descriptor(
  name='ReservationEstimatedCoverage',
  full_name='blueapi.api.aws.ReservationEstimatedCoverage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountId', full_name='blueapi.api.aws.ReservationEstimatedCoverage.accountId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCode', full_name='blueapi.api.aws.ReservationEstimatedCoverage.productCode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='riCoverage', full_name='blueapi.api.aws.ReservationEstimatedCoverage.riCoverage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ec2SpCoverage', full_name='blueapi.api.aws.ReservationEstimatedCoverage.ec2SpCoverage', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computeSpCoverage', full_name='blueapi.api.aws.ReservationEstimatedCoverage.computeSpCoverage', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1338,
  serialized_end=1478,
)

_AWSRECOMMENDATIONS.fields_by_name['summary'].message_type = _RESERVATIONRECOMMENDATIONSUMMARY
_AWSRECOMMENDATIONS.fields_by_name['riRecommendations'].message_type = _RIRECOMMENDATION
_AWSRECOMMENDATIONS.fields_by_name['spRecommendations'].message_type = _SPRECOMMENDATION
_AWSRECOMMENDATIONS.fields_by_name['estimatedCoverage'].message_type = _RESERVATIONESTIMATEDCOVERAGE
DESCRIPTOR.message_types_by_name['AwsRecommendations'] = _AWSRECOMMENDATIONS
DESCRIPTOR.message_types_by_name['RiRecommendation'] = _RIRECOMMENDATION
DESCRIPTOR.message_types_by_name['SpRecommendation'] = _SPRECOMMENDATION
DESCRIPTOR.message_types_by_name['ReservationRecommendationSummary'] = _RESERVATIONRECOMMENDATIONSUMMARY
DESCRIPTOR.message_types_by_name['ReservationEstimatedCoverage'] = _RESERVATIONESTIMATEDCOVERAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AwsRecommendations = _reflection.GeneratedProtocolMessageType('AwsRecommendations', (_message.Message,), {
  'DESCRIPTOR' : _AWSRECOMMENDATIONS,
  '__module__' : 'api.aws.recommendation_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.AwsRecommendations)
  })
_sym_db.RegisterMessage(AwsRecommendations)

RiRecommendation = _reflection.GeneratedProtocolMessageType('RiRecommendation', (_message.Message,), {
  'DESCRIPTOR' : _RIRECOMMENDATION,
  '__module__' : 'api.aws.recommendation_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.RiRecommendation)
  })
_sym_db.RegisterMessage(RiRecommendation)

SpRecommendation = _reflection.GeneratedProtocolMessageType('SpRecommendation', (_message.Message,), {
  'DESCRIPTOR' : _SPRECOMMENDATION,
  '__module__' : 'api.aws.recommendation_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.SpRecommendation)
  })
_sym_db.RegisterMessage(SpRecommendation)

ReservationRecommendationSummary = _reflection.GeneratedProtocolMessageType('ReservationRecommendationSummary', (_message.Message,), {
  'DESCRIPTOR' : _RESERVATIONRECOMMENDATIONSUMMARY,
  '__module__' : 'api.aws.recommendation_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.ReservationRecommendationSummary)
  })
_sym_db.RegisterMessage(ReservationRecommendationSummary)

ReservationEstimatedCoverage = _reflection.GeneratedProtocolMessageType('ReservationEstimatedCoverage', (_message.Message,), {
  'DESCRIPTOR' : _RESERVATIONESTIMATEDCOVERAGE,
  '__module__' : 'api.aws.recommendation_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.ReservationEstimatedCoverage)
  })
_sym_db.RegisterMessage(ReservationEstimatedCoverage)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from os import getenv
import requests

ALPHAUS_CLIENT_ID = "ALPHAUS_CLIENT_ID"
ALPHAUS_CLIENT_SECRET = "ALPHAUS_CLIENT_SECRET"
ALPHAUS_USERNAME = "ALPHAUS_USERNAME"
ALPHAUS_PASSWORD = "ALPHAUS_PASSWORD"
ALPHAUS_AUTH_URL = "ALPHAUS_AUTH_URL"

ALPHAUS_RIPPLE_CLIENT_ID = "ALPHAUS_RIPPLE_CLIENT_ID"
ALPHAUS_RIPPLE_CLIENT_SECRET = "ALPHAUS_RIPPLE_CLIENT_SECRET"
ALPHAUS_RIPPLE_USERNAME = "ALPHAUS_RIPPLE_USERNAME"
ALPHAUS_RIPPLE_PASSWORD = "ALPHAUS_RIPPLE_PASSWORD"
ALPHAUS_WAVE_CLIENT_ID = "ALPHAUS_WAVE_CLIENT_ID"
ALPHAUS_WAVE_CLIENT_SECRET = "ALPHAUS_WAVE_CLIENT_SECRET"
ALPHAUS_WAVE_USERNAME = "ALPHAUS_WAVE_USERNAME"
ALPHAUS_WAVE_PASSWORD = "ALPHAUS_WAVE_PASSWORD"

LOGIN_URL_RIPPLE = "https://login.alphaus.cloud/ripple/access_token"
LOGIN_URL_WAVE = "https://login.alphaus.cloud/access_token"
LOGIN_URL_RIPPLE_NEXT = "https://loginnext.alphaus.cloud/ripple/access_token"
LOGIN_URL_WAVE_NEXT = "https://loginnext.alphaus.cloud/access_token"

class Session(object):
    """
    Session contains all the functionality necessary to manage connections to the Blue API
    """

    def __init__(self, client_id: str = None, client_secret: str = None, grant_type: str = None, 
        scope: str = None, username: str = None, password: str = None, login_url: str = None):
        """
        Creates a new Session object from the data necessary to connect to the Blue API.
        @param client_id: The ID of the client registered with Blue
        @param client_secret: The secret associated with the client ID, registered with Blue
        @param grant_type: The grant type to associate with the request. If no value is
            provided then the value will be assumed based on the credentials provided:
            - "client_credentials" if no username and password could be found for the
                credentials provided
            - "password" if a username and password could be found
        @param scope: The scope associated with the request. If no value is provided then
            the value "openid" will be assumed
        @param username: The username to authenticate with the Blue API
        @param password: The password associated with the username being authenticated
        @param login_url: The login URL being authenticated against. If the appropriate client
            credentials could be found or were provided, then this value will be used. If no
            credentials were provided, then the value for the URL will be assumed based on the
            note included below. If credentials were provided, but hte URL was not defined then
            its value will be pulled from the ALPHAUS_AUTH_URL environment variable. If this value
            is not defined then the LOGIN_URL_RIPPLE will be used.

        If no value is provided for client_id or client_secret, then various combinations of
        values will be checked, in the following order:
        - ALPHAUS_CLIENT_ID and ALPHAUS_CLIENT_SECRET will be used for the client credentials.
            If the username and password were provided then these will be used. Otherwise, the
            values will be pulled from the ALPHAUS_USERNAME and ALPHAUS_PASSWORD environment variables.
        - ALPHAUS_RIPPLE_CLIENT_ID and ALPHAUS_RIPPLE_CLIENT_SECRET will be used for the client
            credentials. In this case, the username and password will be pulled from the ALPHAUS_RIPPLE_USERNAME
            and ALPHAUS_RIPPLE_PASSWORD environment variables and the login URL will be set to the LOGIN_URL_RIPPLE.
        - ALPHAUS_WAVE_CLIENT_ID and ALPHAUS_WAVE_CLIENT_SECRET will be used for the client credentials.
            In this case, the username and password will be pulled from the ALPHAUS_WAVE_USERNAME
            and ALPHAUS_WAVE_PASSWORD environment variables and the login URL will be set to the LOGIN_URL_WAVE.
        """

        # Helper function that produces either the value provided, or the value associated
        # with the environment variable name if the value was None
        def _get_local_credential_from_env(value: str, env_key: str) -> str:
            return getenv(env_key) if value is None else value
        
        # Helper function that produces either the value provided or the alternative if the
        # value was None
        def _get_local_credential_from_choices(value: str, alternative: str) -> str:
            return alternative if value is None else value
        
        # Helper function that attempts to retrieve the client credentials if they were not set
        def _update_auth_details(client_id_key: str, client_secret_key: str, username_key: str, password_key: str, url: str) -> None:

            # If the client ID and secret are both present then there's nothing to do here so return
            if not (self.ClientId and self.ClientSecret):

                # The client ID and secret were not provided so attempt to retrieve them from the
                # associated environment variables that were provided
                self.ClientId = getenv(client_id_key)
                self.ClientSecret = getenv(client_secret_key)

                # If we found the client credentials then also attempt to get the username and
                # password from the associated environment variables. Also, set the URL
                if self.ClientId and self.ClientSecret:
                    self.Username = getenv(username_key)
                    self.Password = getenv(password_key)
                    self.LoginUrl = url

        # First, set the client credentials, scope and login URL from the values received with the function call
        # or pulled from the appropriate values or environment variables if not provided
        self.ClientId = _get_local_credential_from_env(client_id, ALPHAUS_CLIENT_ID)
        self.ClientSecret = _get_local_credential_from_env(client_secret, ALPHAUS_CLIENT_SECRET)
        self.Scope = _get_local_credential_from_choices(scope, "openid")
        self.Username = _get_local_credential_from_env(username, ALPHAUS_USERNAME)
        self.Password = _get_local_credential_from_env(password, ALPHAUS_PASSWORD)
        self.LoginUrl = _get_local_credential_from_choices(
            _get_local_credential_from_env(login_url, ALPHAUS_AUTH_URL), LOGIN_URL_RIPPLE)

        # Next, update the client credentials if they were not provided in a cascading order
        _update_auth_details(ALPHAUS_RIPPLE_CLIENT_ID, ALPHAUS_RIPPLE_CLIENT_SECRET, 
            ALPHAUS_RIPPLE_USERNAME, ALPHAUS_RIPPLE_PASSWORD, LOGIN_URL_RIPPLE)
        _update_auth_details(ALPHAUS_WAVE_CLIENT_ID, ALPHAUS_WAVE_CLIENT_SECRET,
            ALPHAUS_WAVE_USERNAME, ALPHAUS_WAVE_PASSWORD, LOGIN_URL_WAVE)

        # Finally, update the grant type if it was not provided
        if grant_type is None:
            if self.Username and self.Password:
                self.GrantType = "password"
            else:
                self.GrantType = "client_credentials"
        else:
            self.GrantType = grant_type

    def access_token(self) -> str:
        """
        Authenticates the user with the Blue API using the credentials provided.
        @returns: An access token that can be used with secured GRPC requests or
            REST requests to access Blue API endpoints
        """

        # First, insert the base fields into the form data
        form = [
            ("client_id", self.ClientId),
            ("client_secret", self.ClientSecret),
            ("grant_type", self.GrantType),
            ("scope", self.Scope)
        ]

        # Next, if the grant type is password then add the username and password
        # to the form data as well
        if self.GrantType == "password":
            form.extend(("username", self.Username), ("pass"))
        
        # Now, attempt to post the form request with a timeout of 60s. If the response
        # code from this request is not in a 2xx then throw an exception
        resp = requests.post(self.LoginUrl, timeout = 60, data = form)
        if resp.status_code < 200 or resp.status_code >= 300:
            raise Exception(resp.status_code)
        
        # Finally, attempt to extract the access token from the response. If we couldn't
        # find it then throw an exception
        mapping = resp.json()
        if "access_token" in mapping:
            return mapping["access_token"]
        else:
            raise Exception("Cannot find access token")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/aws/reduction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/aws/reduction.proto',
  package='blueapi.api.aws',
  syntax='proto3',
  serialized_options=b'\n\035cloud.alphaus.blueapi.api.awsB\024ApiAwsReductionProtoZ*github.com/alphauslabs/blue-sdk-go/api/aws',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x61pi/aws/reduction.proto\x12\x0f\x62lueapi.api.aws\"\xc3\x01\n\x11\x41wsCostReductions\x12\x36\n\x07summary\x18\x01 \x01(\x0b\x32%.blueapi.api.aws.CostReductionSummary\x12:\n\x10riCostReductions\x18\x02 \x03(\x0b\x32 .blueapi.api.aws.RiCostReduction\x12:\n\x10spCostReductions\x18\x03 \x03(\x0b\x32 .blueapi.api.aws.SpCostReduction\"\x89\x05\n\x0fRiCostReduction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x12\n\ncustomerId\x18\x03 \x01(\t\x12\x14\n\x0c\x63ustomerName\x18\x04 \x01(\t\x12\x11\n\tcompanyId\x18\x05 \x01(\t\x12\x16\n\x0e\x62illingGroupId\x18\x06 \x01(\t\x12\x18\n\x10\x62illingGroupName\x18\x07 \x01(\t\x12\x16\n\x0e\x64\x65stCustomerId\x18\x08 \x01(\t\x12\r\n\x05start\x18\t \x01(\t\x12\x0b\n\x03\x65nd\x18\n \x01(\t\x12\x0f\n\x07service\x18\x0b \x01(\t\x12\x14\n\x0cinstanceType\x18\x0c \x01(\t\x12\x1a\n\x12modificationStatus\x18\r \x01(\t\x12\x0e\n\x06number\x18\x0e \x01(\x03\x12\x12\n\nofferClass\x18\x0f \x01(\t\x12\x0e\n\x06paidBy\x18\x10 \x01(\t\x12\x15\n\rpaymentOption\x18\x11 \x01(\t\x12\x10\n\x08platform\x18\x12 \x01(\t\x12\x0e\n\x06region\x18\x13 \x01(\t\x12\x0e\n\x06remove\x18\x14 \x01(\t\x12\r\n\x05scope\x18\x15 \x01(\t\x12\x0f\n\x07tenancy\x18\x16 \x01(\t\x12\x12\n\ntermLength\x18\x17 \x01(\t\x12\x11\n\tusageType\x18\x18 \x01(\t\x12\x0e\n\x06vendor\x18\x19 \x01(\t\x12\x0c\n\x04zone\x18\x1a \x01(\t\x12\x10\n\x08\x64isabled\x18\x1b \x01(\t\x12\x1b\n\x13normalizationFactor\x18\x1c \x01(\x01\x12\x15\n\runblendedRate\x18\x1d \x01(\x01\x12\x14\n\x0cupfrontValue\x18\x1e \x01(\x01\x12\x14\n\x0condemandCost\x18\x1f \x01(\x01\x12\x12\n\nactualCost\x18  \x01(\x01\x12\x0f\n\x07savings\x18! \x01(\x01\"\xa6\x03\n\x0fSpCostReduction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x12\n\ncustomerId\x18\x03 \x01(\t\x12\x14\n\x0c\x63ustomerName\x18\x04 \x01(\t\x12\x16\n\x0e\x62illingGroupId\x18\x05 \x01(\t\x12\x18\n\x10\x62illingGroupName\x18\x06 \x01(\t\x12\x10\n\x08\x63urrency\x18\x07 \x01(\t\x12\x0f\n\x07service\x18\x08 \x01(\t\x12\x13\n\x0bsavingsPlan\x18\t \x01(\t\x12\r\n\x05start\x18\n \x01(\t\x12\x0b\n\x03\x65nd\x18\x0b \x01(\t\x12\x0e\n\x06region\x18\x0c \x01(\t\x12\x16\n\x0einstanceFamily\x18\r \x01(\t\x12\x12\n\ntermLength\x18\x0e \x01(\t\x12\x15\n\rpaymentOption\x18\x0f \x01(\t\x12\x12\n\ncommitment\x18\x10 \x01(\x01\x12\x12\n\nupfrontFee\x18\x11 \x01(\x01\x12\x14\n\x0crecurringFee\x18\x12 \x01(\x01\x12\x14\n\x0condemandCost\x18\x13 \x01(\x01\x12\x12\n\nactualCost\x18\x14 \x01(\x01\x12\x0f\n\x07savings\x18\x15 \x01(\x01\"\x80\x02\n\x14\x43ostReductionSummary\x12\x19\n\x11totalOnDemandCost\x18\x01 \x01(\x01\x12\x17\n\x0ftotalActualCost\x18\x02 \x01(\x01\x12\x14\n\x0ctotalSavings\x18\x03 \x01(\x01\x12\x1b\n\x13totalRiOnDemandCost\x18\x04 \x01(\x01\x12\x19\n\x11totalRiActualCost\x18\x05 \x01(\x01\x12\x16\n\x0etotalRiSavings\x18\x06 \x01(\x01\x12\x1b\n\x13totalSpOnDemandCost\x18\x07 \x01(\x01\x12\x19\n\x11totalSpActualCost\x18\x08 \x01(\x01\x12\x16\n\x0etotalSpSavings\x18\t \x01(\x01\x42\x61\n\x1d\x63loud.alphaus.blueapi.api.awsB\x14\x41piAwsReductionProtoZ*github.com/alphauslabs/blue-sdk-go/api/awsb\x06proto3'
)




_AWSCOSTREDUCTIONS = _descriptor.Descriptor(
  name='AwsCostReductions',
  full_name='blueapi.api.aws.AwsCostReductions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='summary', full_name='blueapi.api.aws.AwsCostReductions.summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='riCostReductions', full_name='blueapi.api.aws.AwsCostReductions.riCostReductions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spCostReductions', full_name='blueapi.api.aws.AwsCostReductions.spCostReductions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=240,
)


_RICOSTREDUCTION = _descriptor.Descriptor(
  name='RiCostReduction',
  full_name='blueapi.api.aws.RiCostReduction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.aws.RiCostReduction.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arn', full_name='blueapi.api.aws.RiCostReduction.arn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customerId', full_name='blueapi.api.aws.RiCostReduction.customerId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customerName', full_name='blueapi.api.aws.RiCostReduction.customerName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companyId', full_name='blueapi.api.aws.RiCostReduction.companyId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingGroupId', full_name='blueapi.api.aws.RiCostReduction.billingGroupId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingGroupName', full_name='blueapi.api.aws.RiCostReduction.billingGroupName', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destCustomerId', full_name='blueapi.api.aws.RiCostReduction.destCustomerId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='blueapi.api.aws.RiCostReduction.start', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='blueapi.api.aws.RiCostReduction.end', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='blueapi.api.aws.RiCostReduction.service', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceType', full_name='blueapi.api.aws.RiCostReduction.instanceType', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modificationStatus', full_name='blueapi.api.aws.RiCostReduction.modificationStatus', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='blueapi.api.aws.RiCostReduction.number', index=13,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offerClass', full_name='blueapi.api.aws.RiCostReduction.offerClass', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paidBy', full_name='blueapi.api.aws.RiCostReduction.paidBy', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paymentOption', full_name='blueapi.api.aws.RiCostReduction.paymentOption', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform', full_name='blueapi.api.aws.RiCostReduction.platform', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='blueapi.api.aws.RiCostReduction.region', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove', full_name='blueapi.api.aws.RiCostReduction.remove', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='blueapi.api.aws.RiCostReduction.scope', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tenancy', full_name='blueapi.api.aws.RiCostReduction.tenancy', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='termLength', full_name='blueapi.api.aws.RiCostReduction.termLength', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usageType', full_name='blueapi.api.aws.RiCostReduction.usageType', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.api.aws.RiCostReduction.vendor', index=24,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='blueapi.api.aws.RiCostReduction.zone', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='blueapi.api.aws.RiCostReduction.disabled', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalizationFactor', full_name='blueapi.api.aws.RiCostReduction.normalizationFactor', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unblendedRate', full_name='blueapi.api.aws.RiCostReduction.unblendedRate', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upfrontValue', full_name='blueapi.api.aws.RiCostReduction.upfrontValue', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ondemandCost', full_name='blueapi.api.aws.RiCostReduction.ondemandCost', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualCost', full_name='blueapi.api.aws.RiCostReduction.actualCost', index=31,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='savings', full_name='blueapi.api.aws.RiCostReduction.savings', index=32,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=892,
)


_SPCOSTREDUCTION = _descriptor.Descriptor(
  name='SpCostReduction',
  full_name='blueapi.api.aws.SpCostReduction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.aws.SpCostReduction.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arn', full_name='blueapi.api.aws.SpCostReduction.arn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customerId', full_name='blueapi.api.aws.SpCostReduction.customerId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customerName', full_name='blueapi.api.aws.SpCostReduction.customerName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingGroupId', full_name='blueapi.api.aws.SpCostReduction.billingGroupId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingGroupName', full_name='blueapi.api.aws.SpCostReduction.billingGroupName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='blueapi.api.aws.SpCostReduction.currency', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='blueapi.api.aws.SpCostReduction.service', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='savingsPlan', full_name='blueapi.api.aws.SpCostReduction.savingsPlan', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='blueapi.api.aws.SpCostReduction.start', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='blueapi.api.aws.SpCostReduction.end', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='blueapi.api.aws.SpCostReduction.region', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceFamily', full_name='blueapi.api.aws.SpCostReduction.instanceFamily', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='termLength', full_name='blueapi.api.aws.SpCostReduction.termLength', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paymentOption', full_name='blueapi.api.aws.SpCostReduction.paymentOption', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commitment', full_name='blueapi.api.aws.SpCostReduction.commitment', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upfrontFee', full_name='blueapi.api.aws.SpCostReduction.upfrontFee', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurringFee', full_name='blueapi.api.aws.SpCostReduction.recurringFee', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ondemandCost', full_name='blueapi.api.aws.SpCostReduction.ondemandCost', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualCost', full_name='blueapi.api.aws.SpCostReduction.actualCost', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='savings', full_name='blueapi.api.aws.SpCostReduction.savings', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=1317,
)


_COSTREDUCTIONSUMMARY = _descriptor.Descriptor(
  name='CostReductionSummary',
  full_name='blueapi.api.aws.CostReductionSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='totalOnDemandCost', full_name='blueapi.api.aws.CostReductionSummary.totalOnDemandCost', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalActualCost', full_name='blueapi.api.aws.CostReductionSummary.totalActualCost', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalSavings', full_name='blueapi.api.aws.CostReductionSummary.totalSavings', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalRiOnDemandCost', full_name='blueapi.api.aws.CostReductionSummary.totalRiOnDemandCost', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalRiActualCost', full_name='blueapi.api.aws.CostReductionSummary.totalRiActualCost', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalRiSavings', full_name='blueapi.api.aws.CostReductionSummary.totalRiSavings', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalSpOnDemandCost', full_name='blueapi.api.aws.CostReductionSummary.totalSpOnDemandCost', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalSpActualCost', full_name='blueapi.api.aws.CostReductionSummary.totalSpActualCost', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalSpSavings', full_name='blueapi.api.aws.CostReductionSummary.totalSpSavings', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1320,
  serialized_end=1576,
)

_AWSCOSTREDUCTIONS.fields_by_name['summary'].message_type = _COSTREDUCTIONSUMMARY
_AWSCOSTREDUCTIONS.fields_by_name['riCostReductions'].message_type = _RICOSTREDUCTION
_AWSCOSTREDUCTIONS.fields_by_name['spCostReductions'].message_type = _SPCOSTREDUCTION
DESCRIPTOR.message_types_by_name['AwsCostReductions'] = _AWSCOSTREDUCTIONS
DESCRIPTOR.message_types_by_name['RiCostReduction'] = _RICOSTREDUCTION
DESCRIPTOR.message_types_by_name['SpCostReduction'] = _SPCOSTREDUCTION
DESCRIPTOR.message_types_by_name['CostReductionSummary'] = _COSTREDUCTIONSUMMARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AwsCostReductions = _reflection.GeneratedProtocolMessageType('AwsCostReductions', (_message.Message,), {
  'DESCRIPTOR' : _AWSCOSTREDUCTIONS,
  '__module__' : 'api.aws.reduction_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.AwsCostReductions)
  })
_sym_db.RegisterMessage(AwsCostReductions)

RiCostReduction = _reflection.GeneratedProtocolMessageType('RiCostReduction', (_message.Message,), {
  'DESCRIPTOR' : _RICOSTREDUCTION,
  '__module__' : 'api.aws.reduction_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.RiCostReduction)
  })
_sym_db.RegisterMessage(RiCostReduction)

SpCostReduction = _reflection.GeneratedProtocolMessageType('SpCostReduction', (_message.Message,), {
  'DESCRIPTOR' : _SPCOSTREDUCTION,
  '__module__' : 'api.aws.reduction_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.SpCostReduction)
  })
_sym_db.RegisterMessage(SpCostReduction)

CostReductionSummary = _reflection.GeneratedProtocolMessageType('CostReductionSummary', (_message.Message,), {
  'DESCRIPTOR' : _COSTREDUCTIONSUMMARY,
  '__module__' : 'api.aws.reduction_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.CostReductionSummary)
  })
_sym_db.RegisterMessage(CostReductionSummary)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/apiclient.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/apiclient.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\021ApiApiClientProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13\x61pi/apiclient.proto\x12\x0b\x62lueapi.api\"x\n\tApiClient\x12\x10\n\x08\x63lientId\x18\x01 \x01(\t\x12\x14\n\x0c\x63lientSecret\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tgrantType\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12\x12\n\ncreateTime\x18\x06 \x01(\tBV\n\x19\x63loud.alphaus.blueapi.apiB\x11\x41piApiClientProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
)




_APICLIENT = _descriptor.Descriptor(
  name='ApiClient',
  full_name='blueapi.api.ApiClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientId', full_name='blueapi.api.ApiClient.clientId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientSecret', full_name='blueapi.api.ApiClient.clientSecret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.api.ApiClient.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grantType', full_name='blueapi.api.ApiClient.grantType', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='blueapi.api.ApiClient.parent', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createTime', full_name='blueapi.api.ApiClient.createTime', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=156,
)

DESCRIPTOR.message_types_by_name['ApiClient'] = _APICLIENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ApiClient = _reflection.GeneratedProtocolMessageType('ApiClient', (_message.Message,), {
  'DESCRIPTOR' : _APICLIENT,
  '__module__' : 'api.apiclient_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.ApiClient)
  })
_sym_db.RegisterMessage(ApiClient)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: operations/v1/operations.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from alphausblue.api import operation_pb2 as api_dot_operation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='operations/v1/operations.proto',
  package='blueapi.operations.v1',
  syntax='proto3',
  serialized_options=b'\n\034cloud.alphaus.api.operationsB\017OperationsProtoZ)github.com/alphauslabs/blueapi/operations',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eoperations/v1/operations.proto\x12\x15\x62lueapi.operations.v1\x1a\x13\x61pi/operation.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"J\n\x15ListOperationsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x0c\n\x04\x61sOf\x18\x02 \x01(\t\x12\x13\n\x0bincludeDone\x18\x03 \x01(\x08\"#\n\x13GetOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"&\n\x16\x44\x65leteOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"&\n\x16\x43\x61ncelOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"P\n\x14WaitOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xcc\x05\n\nOperations\x12i\n\x0eListOperations\x12,.blueapi.operations.v1.ListOperationsRequest\x1a\x16.blueapi.api.Operation\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/ops/v10\x01\x12j\n\x0cGetOperation\x12*.blueapi.operations.v1.GetOperationRequest\x1a\x16.blueapi.api.Operation\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/ops/v1/{name}\x12p\n\x0f\x44\x65leteOperation\x12-.blueapi.operations.v1.DeleteOperationRequest\x1a\x16.google.protobuf.Empty\"\x16\x82\xd3\xe4\x93\x02\x10*\x0e/ops/v1/{name}\x12z\n\x0f\x43\x61ncelOperation\x12-.blueapi.operations.v1.CancelOperationRequest\x1a\x16.google.protobuf.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/ops/v1/{name}:cancel:\x01*\x12V\n\rWaitOperation\x12+.blueapi.operations.v1.WaitOperationRequest\x1a\x16.blueapi.api.Operation\"\x00\x1a\xa0\x01\x92\x41\x9c\x01\x12\x46(BETA) Long operations API. Base URL: https://api.alphaus.cloud/m/blue\x1aR\n\x12Service definition\x12<https://github.com/alphauslabs/blueapi/tree/main/operations/BZ\n\x1c\x63loud.alphaus.api.operationsB\x0fOperationsProtoZ)github.com/alphauslabs/blueapi/operationsb\x06proto3'
  ,
  dependencies=[api_dot_operation__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,protoc__gen__openapiv2_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_LISTOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListOperationsRequest',
  full_name='blueapi.operations.v1.ListOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='blueapi.operations.v1.ListOperationsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asOf', full_name='blueapi.operations.v1.ListOperationsRequest.asOf', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeDone', full_name='blueapi.operations.v1.ListOperationsRequest.includeDone', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=291,
)


_GETOPERATIONREQUEST = _descriptor.Descriptor(
  name='GetOperationRequest',
  full_name='blueapi.operations.v1.GetOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.operations.v1.GetOperationRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=328,
)


_DELETEOPERATIONREQUEST = _descriptor.Descriptor(
  name='DeleteOperationRequest',
  full_name='blueapi.operations.v1.DeleteOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.operations.v1.DeleteOperationRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=368,
)


_CANCELOPERATIONREQUEST = _descriptor.Descriptor(
  name='CancelOperationRequest',
  full_name='blueapi.operations.v1.CancelOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.operations.v1.CancelOperationRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=408,
)


_WAITOPERATIONREQUEST = _descriptor.Descriptor(
  name='WaitOperationRequest',
  full_name='blueapi.operations.v1.WaitOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.operations.v1.WaitOperationRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='blueapi.operations.v1.WaitOperationRequest.timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=490,
)

_WAITOPERATIONREQUEST.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['ListOperationsRequest'] = _LISTOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['GetOperationRequest'] = _GETOPERATIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteOperationRequest'] = _DELETEOPERATIONREQUEST
DESCRIPTOR.message_types_by_name['CancelOperationRequest'] = _CANCELOPERATIONREQUEST
DESCRIPTOR.message_types_by_name['WaitOperationRequest'] = _WAITOPERATIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListOperationsRequest = _reflection.GeneratedProtocolMessageType('ListOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOPERATIONSREQUEST,
  '__module__' : 'operations.v1.operations_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.operations.v1.ListOperationsRequest)
  })
_sym_db.RegisterMessage(ListOperationsRequest)

GetOperationRequest = _reflection.GeneratedProtocolMessageType('GetOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOPERATIONREQUEST,
  '__module__' : 'operations.v1.operations_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.operations.v1.GetOperationRequest)
  })
_sym_db.RegisterMessage(GetOperationRequest)

DeleteOperationRequest = _reflection.GeneratedProtocolMessageType('DeleteOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOPERATIONREQUEST,
  '__module__' : 'operations.v1.operations_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.operations.v1.DeleteOperationRequest)
  })
_sym_db.RegisterMessage(DeleteOperationRequest)

CancelOperationRequest = _reflection.GeneratedProtocolMessageType('CancelOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELOPERATIONREQUEST,
  '__module__' : 'operations.v1.operations_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.operations.v1.CancelOperationRequest)
  })
_sym_db.RegisterMessage(CancelOperationRequest)

WaitOperationRequest = _reflection.GeneratedProtocolMessageType('WaitOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _WAITOPERATIONREQUEST,
  '__module__' : 'operations.v1.operations_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.operations.v1.WaitOperationRequest)
  })
_sym_db.RegisterMessage(WaitOperationRequest)


DESCRIPTOR._options = None

_OPERATIONS = _descriptor.ServiceDescriptor(
  name='Operations',
  full_name='blueapi.operations.v1.Operations',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\222A\234\001\022F(BETA) Long operations API. Base URL: https://api.alphaus.cloud/m/blue\032R\n\022Service definition\022<https://github.com/alphauslabs/blueapi/tree/main/operations/',
  create_key=_descriptor._internal_create_key,
  serialized_start=493,
  serialized_end=1209,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='blueapi.operations.v1.Operations.ListOperations',
    index=0,
    containing_service=None,
    input_type=_LISTOPERATIONSREQUEST,
    output_type=api_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\t\022\007/ops/v1',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOperation',
    full_name='blueapi.operations.v1.Operations.GetOperation',
    index=1,
    containing_service=None,
    input_type=_GETOPERATIONREQUEST,
    output_type=api_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\020\022\016/ops/v1/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteOperation',
    full_name='blueapi.operations.v1.Operations.DeleteOperation',
    index=2,
    containing_service=None,
    input_type=_DELETEOPERATIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\020*\016/ops/v1/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelOperation',
    full_name='blueapi.operations.v1.Operations.CancelOperation',
    index=3,
    containing_service=None,
    input_type=_CANCELOPERATIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\032\"\025/ops/v1/{name}:cancel:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitOperation',
    full_name='blueapi.operations.v1.Operations.WaitOperation',
    index=4,
    containing_service=None,
    input_type=_WAITOPERATIONREQUEST,
    output_type=api_dot_operation__pb2._OPERATION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OPERATIONS)

DESCRIPTOR.services_by_name['Operations'] = _OPERATIONS

# @@protoc_insertion_point(module_scope)
